Summary: Server daemons for IMAP and POP network mail protocols.
Name: imap
Version: 2001a
Release: 2
%define srcver 2001a
Group: System Environment/Daemons
Copyright: BSD
Url: http://www.washington.edu/imap/
Packager: Hao Li <hli@haoli.org>
Source0: ftp://ftp.cac.washington.edu/imap/imap-%{srcver}.tar.Z
Source1: ftp://ftp.cac.washington.edu/imap/imap-utils.tar.Z
Source2: imap.pamd
Source3: imap-xinetd
Source4: ipop2-xinetd
Source5: ipop3-xinetd
Source6: imaps-xinetd
Source7: pop3s-xinetd
# Hao Li's patches to optimize imap
Patch0:  imap-cflags.patch
Patch1:  imap-defaultmbx.patch
Patch2:  imap-stripdrivers.patch
Patch3:  imap-ignoredotfiles.patch
Prereq: pam >= 0.59, /etc/pam.d/system-auth, xinetd
Buildroot: /var/tmp/%{name}-root
BuildRequires: openssl-devel

%description
The imap package provides server daemons for both the IMAP (Internet
Message Access Protocol) and POP (Post Office Protocol) mail access
protocols.  The POP protocol uses a "post office" machine to collect mail
for users and allows users to download their mail to their local machine
for reading. The IMAP protocol provides the functionality of POP, but
allows a user to read mail on a remote machine without downloading it to
their local machine.

Install the imap package if you need a server to support the IMAP or the
POP mail access protocols.


%package utils
Summary: IMAP utilities.
Group: Applications/Mail

%description utils
The utilities for manipulating IMAP folders etc.


%package devel
Summary: Development tools for programs which will use the IMAP library.
Group: Development/Libraries

%description devel
The imap-devel package contains the header files and static libraries
for developing programs which will use the IMAP (Internet Message
Access Protocol) library.


%prep
%setup -q -n imap-%{srcver} -a 1
%patch0 -p1
#%patch1 -p1
%patch2 -p1
%patch3 -p1


%build
make lnp \
	EXTRADRIVERS= \
	SSLTYPE=unix \
	SSLCRYPTO=-lcrypto \
	SSLRSA= \
	SSLCERTS=/etc/mail/certs \
	SSLINCLUDE=/usr/include/openssl \
	SSLLIB=/usr/lib

# make imap-utils. Everything from imap-utils except mlock goes into 
# imap-utils RPM. mlock goes into imap RPM. mtest in imap source
# goes into imap-utils RPM.
#
# We must install mlock together with imap and pop daemons and install 
# it setgid mail because Red Hat Linux uses (0775,root,mail) as mail 
# spool protection. Not having /etc/mlock installed will cause a lot of 
# such warnings in /var/log/maillog:
#	sipop3[7835]: Mailbox vulnerable - directory /var/spool/mail 
#	must have 1777 protection
# See docs/FAQ for more details.

mkdir -p utils/{bin,man}
for i in `tar ztf %{SOURCE1}|egrep /$|sed 's|/$||'`; do
    make -C $i C=../c-client
    if [ $i != "mlock" ]; then
	install -m755 -s $i/$i utils/bin
	install -m644 $i/$i.1  utils/man
    fi
done


%install
rm -rf $RPM_BUILD_ROOT
# install imap
mkdir -p $RPM_BUILD_ROOT/{usr/{bin,sbin,man/man8},etc/{pam.d,xinetd.d}}
install -m755 -s {ipopd/{ipop2d,ipop3d},imapd/imapd} $RPM_BUILD_ROOT/usr/sbin
install -m644 src/{ipopd/ipopd.8c,imapd/imapd.8c} $RPM_BUILD_ROOT/usr/man/man8
install -m644 %{SOURCE2} $RPM_BUILD_ROOT/etc/pam.d/imap
install -m644 %{SOURCE2} $RPM_BUILD_ROOT/etc/pam.d/pop
install -m644 %{SOURCE3} $RPM_BUILD_ROOT/etc/xinetd.d/imap
install -m644 %{SOURCE4} $RPM_BUILD_ROOT/etc/xinetd.d/ipop2
install -m644 %{SOURCE5} $RPM_BUILD_ROOT/etc/xinetd.d/ipop3
install -m644 %{SOURCE6} $RPM_BUILD_ROOT/etc/xinetd.d/imaps
install -m644 %{SOURCE7} $RPM_BUILD_ROOT/etc/xinetd.d/pop3s
install -m755 -s mlock/mlock $RPM_BUILD_ROOT/etc
install -m755 -s mtest/mtest $RPM_BUILD_ROOT/usr/bin

# SSL certificates
mkdir -p  $RPM_BUILD_ROOT/etc/mail/certs
touch     $RPM_BUILD_ROOT/etc/mail/certs/{imapd,ipop3d}.pem
chmod 600 $RPM_BUILD_ROOT/etc/mail/certs/{imapd,ipop3d}.pem

# install imap-utils. Even though the source of imap-utils doesn't change
# every time imap has a newer version, there is a chance that c-client
# (which is part of imap and imap-utils depends on) changes so imap-utils
# needs to be re-compiled.
mkdir -p $RPM_BUILD_ROOT/usr/{bin,man/man1}
install -m755 utils/bin/* $RPM_BUILD_ROOT/usr/bin
install -m644 utils/man/* $RPM_BUILD_ROOT/usr/man/man1
ln -s imapcopy $RPM_BUILD_ROOT/usr/bin/imapmove
ln -s mbxcopy  $RPM_BUILD_ROOT/usr/bin/mbxmove

# install imap-devel
mkdir -p $RPM_BUILD_ROOT/usr/{lib,include/imap}
install -m 644 c-client/c-client.a $RPM_BUILD_ROOT/usr/lib
# php requires this to detect IMAP libraries
ln -s c-client.a $RPM_BUILD_ROOT/usr/lib/libc-client.a
install -m 644 c-client/*.h $RPM_BUILD_ROOT/usr/include/imap
install -m 644 src/osdep/tops-20/shortsym.h $RPM_BUILD_ROOT/usr/include/imap


%post
/sbin/service xinetd reload > /dev/null 2>&1 || :

%postun
/sbin/service xinetd reload > /dev/null 2>&1 || :


%files
%defattr(-,root,root)
%doc CONTENTS CPYRIGHT README SUPPORT WARNING docs
%config /etc/pam.d/*
%config /etc/xinetd.d/*
%config /etc/mail/certs/*
%attr(0755,root,root) /usr/sbin/*
/usr/man/man8/*
%attr(2755,root,mail) /etc/mlock


%files utils
%defattr(-,root,root)
/usr/bin/*
/usr/man/man1/*


%files devel
%defattr(-,root,root)
/usr/include/imap
/usr/lib/*


%clean
rm -rf $RPM_BUILD_ROOT


%changelog
* Fri Aug 25 2000 Hao Li <hli@wag.caltech.edu>
  Things to do after RPM install, to get SSL working:

- Generate server certificate and make /etc/mail/certs/{imapd,ipop3d}.pem
  symbolic links to it.

- Make sure /etc/services has:

	imaps           993/tcp
	pop3s           995/tcp

  Specifically for Red Hat Linux 6.X, you need to add "imaps" as an alias
  to "simap", and "pop3s" as an alias to "pop3s".

- Make sure /etc/inetd.conf has: 

	pop3s   stream  tcp     nowait  root    /usr/sbin/ipop3d   ipop3d
	imaps   stream  tcp     nowait  root    /usr/sbin/imapd    imapd

  According to docs/SSLBUILD, do *NOT* use TCP wrappers (tcpd) for the 
  imaps and pop3s services!

- You must call the SSL service "imaps" and "pop3s", *not* "simap" or "spop3",
  because this is hard-coded in the UW-IMAP source codes.

